from setuptools import setup

setup(name='sufi_dists',
      version='1.1',
      description='Testing usage of packaging',
      packages=['sufi_dists'],
      author='Sufian Kaki Aslam',
      author_email='sufiankaki@gmail.com',
      zip_safe=False)
